;; Generated package description from loccur.el  -*- no-byte-compile: t -*-
(define-package "loccur" "1.2.4.0.20201130.233958" "Perform an occur-like folding in current buffer" '((emacs "24.3")) :keywords '("matching") :authors '(("Alexey Veretennikov" . "alexey.veretennikov@gmail.com")) :maintainer '("Alexey Veretennikov" . "alexey.veretennikov@gmail.com") :url "https://github.com/fourier/loccur")
